From 1ac8b9e88303bfef488dc37a41ef7ad190dc1f50 Mon Sep 17 00:00:00 2001
From: Kamil Klimek <naresh@tlen.pl>
Date: Thu, 10 Jun 2010 08:55:21 +0200
Subject: [PATCH] support for stream size in imem access module

---
 modules/access/imem.c |   15 ++++++++++++++-
 1 files changed, 14 insertions(+), 1 deletions(-)

diff --git a/modules/access/imem.c b/modules/access/imem.c
index 035f704..6ee4256 100644
--- a/modules/access/imem.c
+++ b/modules/access/imem.c
@@ -115,6 +115,10 @@ static const char *cat_texts[] = {
 #define RELEASE_LONGTEXT N_(\
     "Address of the release callback function")
 
+#define SIZE_TEXT N_("Size")
+#define SIZE_LONGTEXT N_(\
+	"Size of stream in bytes")
+
 vlc_module_begin()
     set_shortname(N_("Memory input"))
     set_description(N_("Memory input"))
@@ -170,6 +174,10 @@ vlc_module_begin()
         change_private()
         change_safe()
 
+    add_string ("imem-size", "0", NULL, SIZE_TEXT, SIZE_LONGTEXT, true) 
+        change_private()
+        change_safe()
+
     add_shortcut("imem")
     set_capability("access_demux", 0)
     set_callbacks(OpenDemux, CloseDemux)
@@ -195,7 +203,7 @@ typedef int  (*imem_get_t)(void *data, const char *cookie,
 typedef void (*imem_release_t)(void *data, const char *cookie, size_t, void *);
 
 /*****************************************************************************
- * Local prototypes
+ * Local prototypes	
  *****************************************************************************/
 
 /* */
@@ -316,6 +324,11 @@ static int OpenAccess(vlc_object_t *object)
     access->pf_seek    = NULL;
     access->p_sys      = (access_sys_t*)sys;
 
+    // we've got size as string, becouse we have no (u)int64_t var functions
+    char * tmpsize = var_InheritString(object, "imem-size");
+    access->info.i_size = strtoull(tmpsize, 0, 10);
+    free(tmpsize);
+
     return VLC_SUCCESS;
 }
 
-- 
1.7.0.2.msysgit.0

